Index: chrome/browser/ui/browser.h |
diff --git a/chrome/browser/ui/browser.h b/chrome/browser/ui/browser.h |
index 7fd04a9364e82c48d1972254c34d4b3875605f41..911b25ef8168d583f12ecd25c52a7959359b689d 100644 |
--- a/chrome/browser/ui/browser.h |
+++ b/chrome/browser/ui/browser.h |
@@ -456,11 +456,10 @@ class Browser : public TabStripModelObserver, |
// Show the first run search engine bubble on the location bar. |
void ShowFirstRunBubble(); |
// If necessary, update the bookmark bar state according to the instant |
// preview state: when instant preview shows suggestions and bookmark bar is |
// still showing attached, hide it. |
- void MaybeUpdateBookmarkBarStateForInstantPreview( |
- const chrome::search::Mode& mode); |
+ void MaybeUpdateBookmarkBarStateForInstantOverlay(); |
FullscreenController* fullscreen_controller() const { |
return fullscreen_controller_.get(); |
@@ -456,11 +456,10 @@ class Browser : public TabStripModelObserver, |
// Show the first run search engine bubble on the location bar. |
void ShowFirstRunBubble(); |
- // If necessary, update the bookmark bar state according to the instant |
- // preview state: when instant preview shows suggestions and bookmark bar is |
+ // If necessary, update the bookmark bar state according to the Instant |
+ // overlay state: when Instant overlay shows suggestions and bookmark bar is |
// still showing attached, hide it. |